@@ -581,6 +581,8 @@ class Custom_Background {
 	 * @deprecated 3.5.0
 	 */
 	public function wp_set_background_image() {
+		check_ajax_referer( 'custom-background' );
+
 		if ( ! current_user_can( 'edit_theme_options' ) || ! isset( $_POST['attachment_id'] ) ) {
 			exit;
 		}
@@ -601,7 +603,7 @@ class Custom_Background {
 		);
 
 		$size = 'thumbnail';
-		if ( in_array( $_POST['size'], $sizes ) ) {
+		if ( in_array( $_POST['size'], $sizes, true ) ) {
 			$size = esc_attr( $_POST['size'] );
 		}
 
