@@ -9,13 +9,14 @@
 /**
  * Constructs the admin menu.
  *
- * The elements in the array are :
- *     0: Menu item name
+ * The elements in the array are:
+ *     0: Menu item name.
  *     1: Minimum level or capability required.
- *     2: The URL of the item's file
- *     3: Class
- *     4: ID
- *     5: Icon for top level menu
+ *     2: The URL of the item's file.
+ *     3: Page title.
+ *     4: Classes.
+ *     5: ID.
+ *     6: Icon for top level menu.
  *
  * @global array $menu
  */
@@ -42,18 +43,29 @@ if ( ! is_multisite() ) {
 	} else {
 		$cap = 'update_languages';
 	}
-	/* translators: %s: number of pending updates */
-	$submenu['index.php'][10] = array( sprintf( __( 'Updates %s' ), "<span class='update-plugins count-{$update_data['counts']['total']}'><span class='update-count'>" . number_format_i18n( $update_data['counts']['total'] ) . '</span></span>' ), $cap, 'update-core.php' );
+	$submenu['index.php'][10] = array(
+		sprintf(
+			/* translators: %s: Number of pending updates. */
+			__( 'Updates %s' ),
+			sprintf(
+				'<span class="update-plugins count-%s"><span class="update-count">%s</span></span>',
+				$update_data['counts']['total'],
+				number_format_i18n( $update_data['counts']['total'] )
+			)
+		),
+		$cap,
+		'update-core.php',
+	);
 	unset( $cap );
 }
 
 $menu[4] = array( '', 'read', 'separator1', '', 'wp-menu-separator' );
 
-// $menu[5] = Posts
+// $menu[5] = Posts.
 
 $menu[10]                     = array( __( 'Media' ), 'upload_files', 'upload.php', '', 'menu-top menu-icon-media', 'menu-media', 'dashicons-admin-media' );
 	$submenu['upload.php'][5] = array( __( 'Library' ), 'upload_files', 'upload.php' );
-	/* translators: add new file */
+	/* translators: Add new file. */
 	$submenu['upload.php'][10] = array( _x( 'Add New', 'file' ), 'upload_files', 'media-new.php' );
 	$i                         = 15;
 foreach ( get_taxonomies_for_attachments( 'objects' ) as $tax ) {
@@ -67,22 +79,22 @@ foreach ( get_taxonomies_for_attachments( 'objects' ) as $tax ) {
 
 $menu[15]                           = array( __( 'Links' ), 'manage_links', 'link-manager.php', '', 'menu-top menu-icon-links', 'menu-links', 'dashicons-admin-links' );
 	$submenu['link-manager.php'][5] = array( _x( 'All Links', 'admin menu' ), 'manage_links', 'link-manager.php' );
-	/* translators: add new links */
+	/* translators: Add new links. */
 	$submenu['link-manager.php'][10] = array( _x( 'Add New', 'link' ), 'manage_links', 'link-add.php' );
 	$submenu['link-manager.php'][15] = array( __( 'Link Categories' ), 'manage_categories', 'edit-tags.php?taxonomy=link_category' );
 
-// $menu[20] = Pages
+// $menu[20] = Pages.
 
 // Avoid the comment count query for users who cannot edit_posts.
 if ( current_user_can( 'edit_posts' ) ) {
 	$awaiting_mod      = wp_count_comments();
 	$awaiting_mod      = $awaiting_mod->moderated;
 	$awaiting_mod_i18n = number_format_i18n( $awaiting_mod );
-	/* translators: %s: number of comments in moderation */
+	/* translators: %s: Number of comments. */
 	$awaiting_mod_text = sprintf( _n( '%s Comment in moderation', '%s Comments in moderation', $awaiting_mod ), $awaiting_mod_i18n );
 
 	$menu[25] = array(
-		/* translators: %s: number of comments in moderation */
+		/* translators: %s: Number of comments. */
 		sprintf( __( 'Comments %s' ), '<span class="awaiting-mod count-' . absint( $awaiting_mod ) . '"><span class="pending-count" aria-hidden="true">' . $awaiting_mod_i18n . '</span><span class="comments-in-moderation-text screen-reader-text">' . $awaiting_mod_text . '</span></span>' ),
 		'edit_posts',
 		'edit-comments.php',
@@ -96,7 +108,7 @@ if ( current_user_can( 'edit_posts' ) ) {
 
 $submenu['edit-comments.php'][0] = array( __( 'All Comments' ), 'edit_posts', 'edit-comments.php' );
 
-$_wp_last_object_menu = 25; // The index of the last top-level menu in the object menu group
+$_wp_last_object_menu = 25; // The index of the last top-level menu in the object menu group.
 
 $types   = (array) get_post_types(
 	array(
@@ -109,7 +121,7 @@ $builtin = array( 'post', 'page' );
 foreach ( array_merge( $builtin, $types ) as $ptype ) {
 	$ptype_obj = get_post_type_object( $ptype );
 	// Check if it should be a submenu.
-	if ( $ptype_obj->show_in_menu !== true ) {
+	if ( true !== $ptype_obj->show_in_menu ) {
 		continue;
 	}
 	$ptype_menu_position = is_int( $ptype_obj->menu_position ) ? $ptype_obj->menu_position : ++$_wp_last_object_menu; // If we're to use $_wp_last_object_menu, increment it first.
@@ -123,12 +135,12 @@ foreach ( array_merge( $builtin, $types ) as $ptype ) {
 		} else {
 			$menu_icon = esc_url( $ptype_obj->menu_icon );
 		}
-	} elseif ( in_array( $ptype, $builtin ) ) {
+	} elseif ( in_array( $ptype, $builtin, true ) ) {
 		$menu_icon = 'dashicons-admin-' . $ptype;
 	}
 
 	$menu_class = 'menu-top menu-icon-' . $ptype_for_id;
-	// 'post' special case
+	// 'post' special case.
 	if ( 'post' === $ptype ) {
 		$menu_class    .= ' open-if-no-js';
 		$ptype_file     = 'edit.php';
@@ -140,7 +152,7 @@ foreach ( array_merge( $builtin, $types ) as $ptype ) {
 		$edit_tags_file = "edit-tags.php?taxonomy=%s&amp;post_type=$ptype";
 	}
 
-	if ( in_array( $ptype, $builtin ) ) {
+	if ( in_array( $ptype, $builtin, true ) ) {
 		$ptype_menu_id = 'menu-' . $ptype_for_id . 's';
 	} else {
 		$ptype_menu_id = 'menu-posts-' . $ptype_for_id;
@@ -150,7 +162,7 @@ foreach ( array_merge( $builtin, $types ) as $ptype ) {
 	 * by a hard-coded value below, increment the position.
 	 */
 	$core_menu_positions = array( 59, 60, 65, 70, 75, 80, 85, 99 );
-	while ( isset( $menu[ $ptype_menu_position ] ) || in_array( $ptype_menu_position, $core_menu_positions ) ) {
+	while ( isset( $menu[ $ptype_menu_position ] ) || in_array( $ptype_menu_position, $core_menu_positions, true ) ) {
 		$ptype_menu_position++;
 	}
 
@@ -197,18 +209,18 @@ if ( current_theme_supports( 'custom-background' ) && current_user_can( 'customi
 
 unset( $appearance_cap );
 
-// Add 'Editor' to the bottom of the Appearance menu.
+// Add 'Theme Editor' to the bottom of the Appearance menu.
 if ( ! is_multisite() ) {
 	add_action( 'admin_menu', '_add_themes_utility_last', 101 );
 }
 /**
- * Adds the (theme) 'Editor' link to the bottom of the Appearance menu.
+ * Adds the 'Theme Editor' link to the bottom of the Appearance menu.
  *
  * @access private
  * @since 3.0.0
  */
 function _add_themes_utility_last() {
-	// Must use API on the admin_menu hook, direct modification is only possible on/before the _admin_menu hook
+	// Must use API on the admin_menu hook, direct modification is only possible on/before the _admin_menu hook.
 	add_submenu_page( 'themes.php', __( 'Theme Editor' ), __( 'Theme Editor' ), 'edit_themes', 'theme-editor.php' );
 }
 
@@ -217,16 +229,20 @@ if ( ! is_multisite() && current_user_can( 'update_plugins' ) ) {
 	if ( ! isset( $update_data ) ) {
 		$update_data = wp_get_update_data();
 	}
-	$count = "<span class='update-plugins count-{$update_data['counts']['plugins']}'><span class='plugin-count'>" . number_format_i18n( $update_data['counts']['plugins'] ) . '</span></span>';
+	$count = sprintf(
+		'<span class="update-plugins count-%s"><span class="plugin-count">%s</span></span>',
+		$update_data['counts']['plugins'],
+		number_format_i18n( $update_data['counts']['plugins'] )
+	);
 }
 
-/* translators: %s: number of pending plugin updates */
+/* translators: %s: Number of pending plugin updates. */
 $menu[65] = array( sprintf( __( 'Plugins %s' ), $count ), 'activate_plugins', 'plugins.php', '', 'menu-top menu-icon-plugins', 'menu-plugins', 'dashicons-admin-plugins' );
 
 $submenu['plugins.php'][5] = array( __( 'Installed Plugins' ), 'activate_plugins', 'plugins.php' );
 
 if ( ! is_multisite() ) {
-	/* translators: add new plugin */
+	/* translators: Add new plugin. */
 	$submenu['plugins.php'][10] = array( _x( 'Add New', 'plugin' ), 'install_plugins', 'plugin-install.php' );
 	$submenu['plugins.php'][15] = array( __( 'Plugin Editor' ), 'edit_plugins', 'plugin-editor.php' );
 }
@@ -248,10 +264,10 @@ if ( current_user_can( 'list_users' ) ) {
 		$submenu['users.php'][10] = array( _x( 'Add New', 'user' ), 'promote_users', 'user-new.php' );
 	}
 
-	$submenu['users.php'][15] = array( __( 'Your Profile' ), 'read', 'profile.php' );
+	$submenu['users.php'][15] = array( __( 'Profile' ), 'read', 'profile.php' );
 } else {
 	$_wp_real_parent_file['users.php'] = 'profile.php';
-	$submenu['profile.php'][5]         = array( __( 'Your Profile' ), 'read', 'profile.php' );
+	$submenu['profile.php'][5]         = array( __( 'Profile' ), 'read', 'profile.php' );
 	if ( current_user_can( 'create_users' ) ) {
 		$submenu['profile.php'][10] = array( __( 'Add New User' ), 'create_users', 'user-new.php' );
 	} elseif ( is_multisite() ) {
@@ -263,9 +279,11 @@ $menu[75]                     = array( __( 'Tools' ), 'edit_posts', 'tools.php',
 	$submenu['tools.php'][5]  = array( __( 'Available Tools' ), 'edit_posts', 'tools.php' );
 	$submenu['tools.php'][10] = array( __( 'Import' ), 'import', 'import.php' );
 	$submenu['tools.php'][15] = array( __( 'Export' ), 'export', 'export.php' );
-	$submenu['tools.php'][20] = array( __( 'Site Health' ), 'install_plugins', 'site-health.php' );
+	$submenu['tools.php'][20] = array( __( 'Site Health' ), 'view_site_health_checks', 'site-health.php' );
+	$submenu['tools.php'][25] = array( __( 'Export Personal Data' ), 'export_others_personal_data', 'export-personal-data.php' );
+	$submenu['tools.php'][30] = array( __( 'Erase Personal Data' ), 'erase_others_personal_data', 'erase-personal-data.php' );
 if ( is_multisite() && ! is_main_site() ) {
-	$submenu['tools.php'][25] = array( __( 'Delete Site' ), 'delete_site', 'ms-delete-site.php' );
+	$submenu['tools.php'][35] = array( __( 'Delete Site' ), 'delete_site', 'ms-delete-site.php' );
 }
 if ( ! is_multisite() && defined( 'WP_ALLOW_MULTISITE' ) && WP_ALLOW_MULTISITE ) {
 	$submenu['tools.php'][50] = array( __( 'Network Setup' ), 'setup_network', 'network.php' );
@@ -278,13 +296,13 @@ $menu[80]                               = array( __( 'Settings' ), 'manage_optio
 	$submenu['options-general.php'][25] = array( __( 'Discussion' ), 'manage_options', 'options-discussion.php' );
 	$submenu['options-general.php'][30] = array( __( 'Media' ), 'manage_options', 'options-media.php' );
 	$submenu['options-general.php'][40] = array( __( 'Permalinks' ), 'manage_options', 'options-permalink.php' );
-	$submenu['options-general.php'][45] = array( __( 'Privacy' ), 'manage_privacy_options', 'privacy.php' );
+	$submenu['options-general.php'][45] = array( __( 'Privacy' ), 'manage_privacy_options', 'options-privacy.php' );
 
-$_wp_last_utility_menu = 80; // The index of the last top-level menu in the utility menu group
+$_wp_last_utility_menu = 80; // The index of the last top-level menu in the utility menu group.
 
 $menu[99] = array( '', 'read', 'separator-last', '', 'wp-menu-separator' );
 
-// Back-compat for old top-levels
+// Back-compat for old top-levels.
 $_wp_real_parent_file['post.php']       = 'edit.php';
 $_wp_real_parent_file['post-new.php']   = 'edit.php';
 $_wp_real_parent_file['edit-pages.php'] = 'edit.php?post_type=page';
@@ -306,4 +324,4 @@ $compat = array(
 	'themes'          => 'appearance',
 );
 
-require_once( ABSPATH . 'wp-admin/includes/menu.php' );
+require_once ABSPATH . 'wp-admin/includes/menu.php';
