@@ -10,8 +10,9 @@
 /**
  * Core base class extended to register widgets.
  *
- * This class must be extended for each widget and WP_Widget::widget(), WP_Widget::update()
- * and WP_Widget::form() need to be overridden.
+ * This class must be extended for each widget, and WP_Widget::widget() must be overridden.
+ *
+ * If adding widget options, WP_Widget::update() and WP_Widget::form() should also be overridden.
  *
  * @since 2.8.0
  * @since 4.4.0 Moved to its own file from wp-includes/widgets.php
@@ -22,7 +23,6 @@ class WP_Widget {
 	 * Root ID for all widgets of this type.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var mixed|string
 	 */
 	public $id_base;
@@ -31,25 +31,38 @@ class WP_Widget {
 	 * Name for this widget type.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var string
 	 */
 	public $name;
 
 	/**
-	 * Option array passed to {@see wp_register_sidebar_widget()}.
+	 * Option name for this widget type.
+	 *
+	 * @since 2.8.0
+	 * @var string
+	 */
+	public $option_name;
+
+	/**
+	 * Alt option name for this widget type.
+	 *
+	 * @since 2.8.0
+	 * @var string
+	 */
+	public $alt_option_name;
+
+	/**
+	 * Option array passed to wp_register_sidebar_widget().
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var array
 	 */
 	public $widget_options;
 
 	/**
-	 * Option array passed to {@see wp_register_widget_control()}.
+	 * Option array passed to wp_register_widget_control().
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var array
 	 */
 	public $control_options;
@@ -58,7 +71,6 @@ class WP_Widget {
 	 * Unique ID number of the current instance.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var bool|int
 	 */
 	public $number = false;
@@ -67,7 +79,6 @@ class WP_Widget {
 	 * Unique ID string of the current instance (id_base-number).
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var bool|string
 	 */
 	public $id = false;
@@ -79,27 +90,27 @@ class WP_Widget {
 	 * not happen twice.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 * @var bool
 	 */
 	public $updated = false;
 
-	// Member functions that you must over-ride.
+	//
+	// Member functions that must be overridden by subclasses.
+	//
 
 	/**
 	 * Echoes the widget content.
 	 *
-	 * Sub-classes should over-ride this function to generate their widget code.
+	 * Subclasses should override this function to generate their widget code.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
 	 * @param array $args     Display arguments including 'before_title', 'after_title',
 	 *                        'before_widget', and 'after_widget'.
 	 * @param array $instance The settings for the particular instance of the widget.
 	 */
 	public function widget( $args, $instance ) {
-		die('function WP_Widget::widget() must be over-ridden in a sub-class.');
+		die( 'function WP_Widget::widget() must be overridden in a subclass.' );
 	}
 
 	/**
@@ -110,7 +121,6 @@ class WP_Widget {
 	 * saved/updated.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
 	 * @param array $new_instance New settings for this instance as input by the user via
 	 *                            WP_Widget::form().
@@ -125,13 +135,12 @@ class WP_Widget {
 	 * Outputs the settings update form.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
 	 * @param array $instance Current settings.
 	 * @return string Default return is 'noform'.
 	 */
 	public function form( $instance ) {
-		echo '<p class="no-options-widget">' . __('There are no options for this widget.') . '</p>';
+		echo '<p class="no-options-widget">' . __( 'There are no options for this widget.' ) . '</p>';
 		return 'noform';
 	}
 
@@ -141,41 +150,55 @@ class WP_Widget {
 	 * PHP5 constructor.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
-	 * @param string $id_base         Optional Base ID for the widget, lowercase and unique. If left empty,
-	 *                                a portion of the widget's class name will be used Has to be unique.
+	 * @param string $id_base         Optional. Base ID for the widget, lowercase and unique. If left empty,
+	 *                                a portion of the widget's class name will be used. Has to be unique.
 	 * @param string $name            Name for the widget displayed on the configuration page.
-	 * @param array  $widget_options  Optional. Widget options. See wp_register_sidebar_widget() for information
-	 *                                on accepted arguments. Default empty array.
+	 * @param array  $widget_options  Optional. Widget options. See wp_register_sidebar_widget() for
+	 *                                information on accepted arguments. Default empty array.
 	 * @param array  $control_options Optional. Widget control options. See wp_register_widget_control() for
 	 *                                information on accepted arguments. Default empty array.
 	 */
 	public function __construct( $id_base, $name, $widget_options = array(), $control_options = array() ) {
-		$this->id_base = empty($id_base) ? preg_replace( '/(wp_)?widget_/', '', strtolower(get_class($this)) ) : strtolower($id_base);
-		$this->name = $name;
-		$this->option_name = 'widget_' . $this->id_base;
-		$this->widget_options = wp_parse_args( $widget_options, array('classname' => $this->option_name) );
-		$this->control_options = wp_parse_args( $control_options, array('id_base' => $this->id_base) );
+		$this->id_base         = empty( $id_base ) ? preg_replace( '/(wp_)?widget_/', '', strtolower( get_class( $this ) ) ) : strtolower( $id_base );
+		$this->name            = $name;
+		$this->option_name     = 'widget_' . $this->id_base;
+		$this->widget_options  = wp_parse_args(
+			$widget_options,
+			array(
+				'classname'                   => $this->option_name,
+				'customize_selective_refresh' => false,
+			)
+		);
+		$this->control_options = wp_parse_args( $control_options, array( 'id_base' => $this->id_base ) );
 	}
 
 	/**
 	 * PHP4 constructor.
 	 *
-	 * @param string $id_base
-	 * @param string $name
-	 * @param array  $widget_options
-	 * @param array  $control_options
+	 * @since 2.8.0
+	 * @deprecated 4.3.0 Use __construct() instead.
+	 *
+	 * @see WP_Widget::__construct()
+	 *
+	 * @param string $id_base         Optional. Base ID for the widget, lowercase and unique. If left empty,
+	 *                                a portion of the widget's class name will be used. Has to be unique.
+	 * @param string $name            Name for the widget displayed on the configuration page.
+	 * @param array  $widget_options  Optional. Widget options. See wp_register_sidebar_widget() for
+	 *                                information on accepted arguments. Default empty array.
+	 * @param array  $control_options Optional. Widget control options. See wp_register_widget_control() for
+	 *                                information on accepted arguments. Default empty array.
 	 */
 	public function WP_Widget( $id_base, $name, $widget_options = array(), $control_options = array() ) {
-		_deprecated_constructor( 'WP_Widget', '4.3.0' );
+		_deprecated_constructor( 'WP_Widget', '4.3.0', get_class( $this ) );
 		WP_Widget::__construct( $id_base, $name, $widget_options, $control_options );
 	}
 
 	/**
 	 * Constructs name attributes for use in form() fields
 	 *
-	 * This function should be used in form() methods to create name attributes for fields to be saved by update()
+	 * This function should be used in form() methods to create name attributes for fields
+	 * to be saved by update()
 	 *
 	 * @since 2.8.0
 	 * @since 4.4.0 Array format field names are now accepted.
@@ -183,8 +206,9 @@ class WP_Widget {
 	 * @param string $field_name Field name
 	 * @return string Name attribute for $field_name
 	 */
-	public function get_field_name($field_name) {
-		if ( false === $pos = strpos( $field_name, '[' ) ) {
+	public function get_field_name( $field_name ) {
+		$pos = strpos( $field_name, '[' );
+		if ( false === $pos ) {
 			return 'widget-' . $this->id_base . '[' . $this->number . '][' . $field_name . ']';
 		} else {
 			return 'widget-' . $this->id_base . '[' . $this->number . '][' . substr_replace( $field_name, '][', $pos, strlen( '[' ) );
@@ -192,14 +216,13 @@ class WP_Widget {
 	}
 
 	/**
-	 * Constructs id attributes for use in {@see WP_Widget::form()} fields.
+	 * Constructs id attributes for use in WP_Widget::form() fields.
 	 *
 	 * This function should be used in form() methods to create id attributes
-	 * for fields to be saved by {@see WP_Widget::update()}.
+	 * for fields to be saved by WP_Widget::update().
 	 *
 	 * @since 2.8.0
 	 * @since 4.4.0 Array format field IDs are now accepted.
-	 * @access public
 	 *
 	 * @param string $field_name Field name.
 	 * @return string ID attribute for `$field_name`.
@@ -212,11 +235,10 @@ class WP_Widget {
 	 * Register all widget instances of this widget class.
 	 *
 	 * @since 2.8.0
-	 * @access private
 	 */
 	public function _register() {
 		$settings = $this->get_settings();
-		$empty = true;
+		$empty    = true;
 
 		// When $settings is an array-like object, get an intrinsic array for use with array_keys().
 		if ( $settings instanceof ArrayObject || $settings instanceof ArrayIterator ) {
@@ -241,40 +263,53 @@ class WP_Widget {
 	}
 
 	/**
-	 * Set the internal order number for the widget instance.
+	 * Sets the internal order number for the widget instance.
 	 *
 	 * @since 2.8.0
-	 * @access private
 	 *
 	 * @param int $number The unique order number of this widget instance compared to other
 	 *                    instances of the same class.
 	 */
-	public function _set($number) {
+	public function _set( $number ) {
 		$this->number = $number;
-		$this->id = $this->id_base . '-' . $number;
+		$this->id     = $this->id_base . '-' . $number;
 	}
 
 	/**
-	 * @return callback
+	 * Retrieves the widget display callback.
+	 *
+	 * @since 2.8.0
+	 *
+	 * @return callable Display callback.
 	 */
 	public function _get_display_callback() {
-		return array($this, 'display_callback');
-	}
-	/**
-	 * @return callback
-	 */
-	public function _get_update_callback() {
-		return array($this, 'update_callback');
-	}
-	/**
-	 * @return callback
-	 */
-	public function _get_form_callback() {
-		return array($this, 'form_callback');
+		return array( $this, 'display_callback' );
 	}
 
 	/**
-	 * Determine whether the current request is inside the Customizer preview.
+	 * Retrieves the widget update callback.
+	 *
+	 * @since 2.8.0
+	 *
+	 * @return callable Update callback.
+	 */
+	public function _get_update_callback() {
+		return array( $this, 'update_callback' );
+	}
+
+	/**
+	 * Retrieves the form callback.
+	 *
+	 * @since 2.8.0
+	 *
+	 * @return callable Form callback.
+	 */
+	public function _get_form_callback() {
+		return array( $this, 'form_callback' );
+	}
+
+	/**
+	 * Determines whether the current request is inside the Customizer preview.
 	 *
 	 * If true -- the current request is inside the Customizer preview, then
 	 * the object cache gets suspended and widgets should check this to decide
@@ -282,7 +317,6 @@ class WP_Widget {
 	 * to transients, or anywhere else.
 	 *
 	 * @since 3.9.0
-	 * @access public
 	 *
 	 * @global WP_Customize_Manager $wp_customize
 	 *
@@ -290,18 +324,17 @@ class WP_Widget {
 	 */
 	public function is_preview() {
 		global $wp_customize;
-		return ( isset( $wp_customize ) && $wp_customize->is_preview() ) ;
+		return ( isset( $wp_customize ) && $wp_customize->is_preview() );
 	}
 
 	/**
-	 * Generate the actual widget content (Do NOT override).
+	 * Generates the actual widget content (Do NOT override).
 	 *
-	 * Finds the instance and calls {@see WP_Widget::widget()}.
+	 * Finds the instance and calls WP_Widget::widget().
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
-	 * @param array     $args        Display arguments. See {@see WP_Widget::widget()} for information
+	 * @param array     $args        Display arguments. See WP_Widget::widget() for information
 	 *                               on accepted arguments.
 	 * @param int|array $widget_args {
 	 *     Optional. Internal order number of the widget instance, or array of multi-widget arguments.
@@ -323,14 +356,14 @@ class WP_Widget {
 			$instance = $instances[ $this->number ];
 
 			/**
-			 * Filter the settings for a particular widget instance.
+			 * Filters the settings for a particular widget instance.
 			 *
 			 * Returning false will effectively short-circuit display of the widget.
 			 *
 			 * @since 2.8.0
 			 *
 			 * @param array     $instance The current widget instance's settings.
-			 * @param WP_Widget $this     The current widget instance.
+			 * @param WP_Widget $widget   The current widget instance.
 			 * @param array     $args     An array of default widget arguments.
 			 */
 			$instance = apply_filters( 'widget_display_callback', $instance, $this, $args );
@@ -353,10 +386,9 @@ class WP_Widget {
 	}
 
 	/**
-	 * Deal with changed settings (Do NOT override).
+	 * Handles changed settings (Do NOT override).
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
 	 * @global array $wp_registered_widgets
 	 *
@@ -367,38 +399,41 @@ class WP_Widget {
 
 		$all_instances = $this->get_settings();
 
-		// We need to update the data
-		if ( $this->updated )
+		// We need to update the data.
+		if ( $this->updated ) {
 			return;
+		}
 
-		if ( isset($_POST['delete_widget']) && $_POST['delete_widget'] ) {
-			// Delete the settings for this instance of the widget
-			if ( isset($_POST['the-widget-id']) )
+		if ( isset( $_POST['delete_widget'] ) && $_POST['delete_widget'] ) {
+			// Delete the settings for this instance of the widget.
+			if ( isset( $_POST['the-widget-id'] ) ) {
 				$del_id = $_POST['the-widget-id'];
-			else
+			} else {
 				return;
+			}
 
-			if ( isset($wp_registered_widgets[$del_id]['params'][0]['number']) ) {
-				$number = $wp_registered_widgets[$del_id]['params'][0]['number'];
+			if ( isset( $wp_registered_widgets[ $del_id ]['params'][0]['number'] ) ) {
+				$number = $wp_registered_widgets[ $del_id ]['params'][0]['number'];
 
-				if ( $this->id_base . '-' . $number == $del_id )
-					unset($all_instances[$number]);
+				if ( $this->id_base . '-' . $number == $del_id ) {
+					unset( $all_instances[ $number ] );
+				}
 			}
 		} else {
-			if ( isset($_POST['widget-' . $this->id_base]) && is_array($_POST['widget-' . $this->id_base]) ) {
-				$settings = $_POST['widget-' . $this->id_base];
-			} elseif ( isset($_POST['id_base']) && $_POST['id_base'] == $this->id_base ) {
-				$num = $_POST['multi_number'] ? (int) $_POST['multi_number'] : (int) $_POST['widget_number'];
+			if ( isset( $_POST[ 'widget-' . $this->id_base ] ) && is_array( $_POST[ 'widget-' . $this->id_base ] ) ) {
+				$settings = $_POST[ 'widget-' . $this->id_base ];
+			} elseif ( isset( $_POST['id_base'] ) && $_POST['id_base'] == $this->id_base ) {
+				$num      = $_POST['multi_number'] ? (int) $_POST['multi_number'] : (int) $_POST['widget_number'];
 				$settings = array( $num => array() );
 			} else {
 				return;
 			}
 
 			foreach ( $settings as $number => $new_instance ) {
-				$new_instance = stripslashes_deep($new_instance);
-				$this->_set($number);
+				$new_instance = stripslashes_deep( $new_instance );
+				$this->_set( $number );
 
-				$old_instance = isset($all_instances[$number]) ? $all_instances[$number] : array();
+				$old_instance = isset( $all_instances[ $number ] ) ? $all_instances[ $number ] : array();
 
 				$was_cache_addition_suspended = wp_suspend_cache_addition();
 				if ( $this->is_preview() && ! $was_cache_addition_suspended ) {
@@ -412,7 +447,7 @@ class WP_Widget {
 				}
 
 				/**
-				 * Filter a widget's settings before saving.
+				 * Filters a widget's settings before saving.
 				 *
 				 * Returning false will effectively short-circuit the widget's ability
 				 * to update settings.
@@ -422,61 +457,66 @@ class WP_Widget {
 				 * @param array     $instance     The current widget instance's settings.
 				 * @param array     $new_instance Array of new widget settings.
 				 * @param array     $old_instance Array of old widget settings.
-				 * @param WP_Widget $this         The current widget instance.
+				 * @param WP_Widget $widget       The current widget instance.
 				 */
 				$instance = apply_filters( 'widget_update_callback', $instance, $new_instance, $old_instance, $this );
 				if ( false !== $instance ) {
-					$all_instances[$number] = $instance;
+					$all_instances[ $number ] = $instance;
 				}
 
-				break; // run only once
+				break; // Run only once.
 			}
 		}
 
-		$this->save_settings($all_instances);
+		$this->save_settings( $all_instances );
 		$this->updated = true;
 	}
 
 	/**
-	 * Generate the widget control form (Do NOT override).
+	 * Generates the widget control form (Do NOT override).
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
-	 * @param int|array $widget_args Widget instance number or array of widget arguments.
+	 * @param int|array $widget_args {
+	 *     Optional. Internal order number of the widget instance, or array of multi-widget arguments.
+	 *     Default 1.
+	 *
+	 *     @type int $number Number increment used for multiples of the same widget.
+	 * }
 	 * @return string|null
 	 */
 	public function form_callback( $widget_args = 1 ) {
-		if ( is_numeric($widget_args) )
+		if ( is_numeric( $widget_args ) ) {
 			$widget_args = array( 'number' => $widget_args );
+		}
 
-		$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );
+		$widget_args   = wp_parse_args( $widget_args, array( 'number' => -1 ) );
 		$all_instances = $this->get_settings();
 
 		if ( -1 == $widget_args['number'] ) {
-			// We echo out a form where 'number' can be set later
-			$this->_set('__i__');
+			// We echo out a form where 'number' can be set later.
+			$this->_set( '__i__' );
 			$instance = array();
 		} else {
-			$this->_set($widget_args['number']);
+			$this->_set( $widget_args['number'] );
 			$instance = $all_instances[ $widget_args['number'] ];
 		}
 
 		/**
-		 * Filter the widget instance's settings before displaying the control form.
+		 * Filters the widget instance's settings before displaying the control form.
 		 *
 		 * Returning false effectively short-circuits display of the control form.
 		 *
 		 * @since 2.8.0
 		 *
 		 * @param array     $instance The current widget instance's settings.
-		 * @param WP_Widget $this     The current widget instance.
+		 * @param WP_Widget $widget   The current widget instance.
 		 */
 		$instance = apply_filters( 'widget_form_callback', $instance, $this );
 
 		$return = null;
 		if ( false !== $instance ) {
-			$return = $this->form($instance);
+			$return = $this->form( $instance );
 
 			/**
 			 * Fires at the end of the widget control form.
@@ -490,7 +530,7 @@ class WP_Widget {
 			 *
 			 * @since 2.8.0
 			 *
-			 * @param WP_Widget $this     The widget instance, passed by reference.
+			 * @param WP_Widget $widget   The widget instance (passed by reference).
 			 * @param null      $return   Return null if new fields are added.
 			 * @param array     $instance An array of the widget's settings.
 			 */
@@ -500,25 +540,23 @@ class WP_Widget {
 	}
 
 	/**
-	 * Register an instance of the widget class.
+	 * Registers an instance of the widget class.
 	 *
 	 * @since 2.8.0
-	 * @access private
 	 *
-	 * @param integer $number Optional. The unique order number of this widget instance
-	 *                        compared to other instances of the same class. Default -1.
+	 * @param int $number Optional. The unique order number of this widget instance
+	 *                    compared to other instances of the same class. Default -1.
 	 */
 	public function _register_one( $number = -1 ) {
-		wp_register_sidebar_widget(	$this->id, $this->name,	$this->_get_display_callback(), $this->widget_options, array( 'number' => $number ) );
+		wp_register_sidebar_widget( $this->id, $this->name, $this->_get_display_callback(), $this->widget_options, array( 'number' => $number ) );
 		_register_widget_update_callback( $this->id_base, $this->_get_update_callback(), $this->control_options, array( 'number' => -1 ) );
-		_register_widget_form_callback(	$this->id, $this->name,	$this->_get_form_callback(), $this->control_options, array( 'number' => $number ) );
+		_register_widget_form_callback( $this->id, $this->name, $this->_get_form_callback(), $this->control_options, array( 'number' => $number ) );
 	}
 
 	/**
-	 * Save the settings for all instances of the widget class.
+	 * Saves the settings for all instances of the widget class.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
 	 * @param array $settings Multi-dimensional array of widget instance settings.
 	 */
@@ -528,10 +566,9 @@ class WP_Widget {
 	}
 
 	/**
-	 * Get the settings for all instances of the widget class.
+	 * Retrieves the settings for all instances of the widget class.
 	 *
 	 * @since 2.8.0
-	 * @access public
 	 *
 	 * @return array Multi-dimensional array of widget instance settings.
 	 */
